# Getting Started with autodidaqt

This autodidaqt application was created through `python -m autodidaqt.runner.template`. To get started, from the directory containing this file activate your environment and run `python app.py`.

If you are using a managed UI around autodidaqt, you do not need to start your application or source your environment: these steps will be handled for you.

## Learning about how to write experiments

Have a look at the autodidaqt documentation for tutorials on how to get started with automating your experiment with autodidaqt.

# What's provided in the template
